#include <R.h>
#include <Rinternals.h>

extern SEXP DBSarrayFnCpp(SEXP nXbasisw, SEXP nWbasisw, SEXP nUbasisj, SEXP nAbasisj,  
                          SEXP AVECJ,    SEXP UCOEFJ,   SEXP BATENS);
